Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
/Users/buh/.pyenv/versions/3.12.2/envs/pii/lib/python3.12/site-packages/es_pii_tool/__init__.py | 3 | 0 | 0 | 100%
/Users/buh/.pyenv/versions/3.12.2/envs/pii/lib/python3.12/site-packages/es_pii_tool/base.py | 100 | 24 | 0 | 76%
/Users/buh/.pyenv/versions/3.12.2/envs/pii/lib/python3.12/site-packages/es_pii_tool/cli.py | 22 | 22 | 0 | 0%
/Users/buh/.pyenv/versions/3.12.2/envs/pii/lib/python3.12/site-packages/es_pii_tool/commands/__init__.py | 0 | 0 | 0 | 100%
/Users/buh/.pyenv/versions/3.12.2/envs/pii/lib/python3.12/site-packages/es_pii_tool/commands/from_yaml.py | 26 | 26 | 0 | 0%
/Users/buh/.pyenv/versions/3.12.2/envs/pii/lib/python3.12/site-packages/es_pii_tool/defaults.py | 21 | 0 | 0 | 100%
/Users/buh/.pyenv/versions/3.12.2/envs/pii/lib/python3.12/site-packages/es_pii_tool/exceptions.py | 68 | 40 | 0 | 41%
/Users/buh/.pyenv/versions/3.12.2/envs/pii/lib/python3.12/site-packages/es_pii_tool/helpers/__init__.py | 0 | 0 | 0 | 100%
/Users/buh/.pyenv/versions/3.12.2/envs/pii/lib/python3.12/site-packages/es_pii_tool/helpers/elastic_api.py | 349 | 118 | 0 | 66%
/Users/buh/.pyenv/versions/3.12.2/envs/pii/lib/python3.12/site-packages/es_pii_tool/helpers/steps.py | 313 | 66 | 0 | 79%
/Users/buh/.pyenv/versions/3.12.2/envs/pii/lib/python3.12/site-packages/es_pii_tool/helpers/utils.py | 188 | 53 | 0 | 72%
/Users/buh/.pyenv/versions/3.12.2/envs/pii/lib/python3.12/site-packages/es_pii_tool/job.py | 217 | 61 | 0 | 72%
/Users/buh/.pyenv/versions/3.12.2/envs/pii/lib/python3.12/site-packages/es_pii_tool/redacters/__init__.py | 0 | 0 | 0 | 100%
/Users/buh/.pyenv/versions/3.12.2/envs/pii/lib/python3.12/site-packages/es_pii_tool/redacters/index.py | 122 | 39 | 0 | 68%
/Users/buh/.pyenv/versions/3.12.2/envs/pii/lib/python3.12/site-packages/es_pii_tool/redacters/snapshot.py | 75 | 8 | 0 | 89%
/Users/buh/.pyenv/versions/3.12.2/envs/pii/lib/python3.12/site-packages/es_pii_tool/redacters/steps.py | 50 | 0 | 0 | 100%
/Users/buh/.pyenv/versions/3.12.2/envs/pii/lib/python3.12/site-packages/es_pii_tool/task.py | 166 | 37 | 0 | 78%
Total | 1720 | 494 | 0 | 71%

No items found using the specified filter.